"""
Routines to calculate statistics about the spatial structure of
point distributions.

.. moduleauthor:: Michael O'Brien <michaelobrien@g.harvard.edu>
.. moduleauthor:: Wen Yan
"""

from .point_cloud import rdf, structure_factor
